@@ -48,6 +48,7 @@ myst_enable_extensions = [
     "substitution",
     "replacements",
     "strikethrough",
+    "linkify",
 ]
 
 templates_path = ["_templates"]
@@ -202,15 +203,14 @@ def linkcode_resolve(domain: str, info: t.Dict[str, str]) -> t.Union[None, str]:
             fn,
             linespec,
         )
-    else:
-        return "{}/blob/v{}/{}/{}/{}{}".format(
-            about["__github__"],
-            about["__version__"],
-            "src",
-            about["__package_name__"],
-            fn,
-            linespec,
-        )
+    return "{}/blob/v{}/{}/{}/{}{}".format(
+        about["__github__"],
+        about["__version__"],
+        "src",
+        about["__package_name__"],
+        fn,
+        linespec,
+    )
 
 
 def remove_tabs_js(app: "Sphinx", exc: Exception) -> None:
