@@ -1,43 +1,45 @@
+"""CLI for ``tmuxp freeze`` subcommand."""
+
 import argparse
+import locale
 import os
 import pathlib
 import sys
 import typing as t
 
 from libtmux.server import Server
-from tmuxp.config_reader import ConfigReader
-from tmuxp.exc import TmuxpException
 
-from .. import config, util
-from ..workspacebuilder import freeze
-from .utils import get_config_dir, prompt, prompt_choices, prompt_yes_no
+from tmuxp import exc, util
+from tmuxp._internal.config_reader import ConfigReader
+from tmuxp.exc import TmuxpException
+from tmuxp.workspace import freezer
+from tmuxp.workspace.finders import get_workspace_dir
+
+from .utils import prompt, prompt_choices, prompt_yes_no
 
 if t.TYPE_CHECKING:
-    from typing_extensions import Literal, TypeAlias, TypeGuard
+    from typing_extensions import TypeAlias, TypeGuard
 
-    CLIOutputFormatLiteral: TypeAlias = Literal["yaml", "json"]
+    CLIOutputFormatLiteral: TypeAlias = t.Literal["yaml", "json"]
 
 
 class CLIFreezeNamespace(argparse.Namespace):
+    """Typed :class:`argparse.Namespace` for tmuxp freeze command."""
+
     session_name: str
     socket_name: t.Optional[str]
     socket_path: t.Optional[str]
-    config_format: t.Optional["CLIOutputFormatLiteral"]
+    workspace_format: t.Optional["CLIOutputFormatLiteral"]
     save_to: t.Optional[str]
     answer_yes: t.Optional[bool]
     quiet: t.Optional[bool]
     force: t.Optional[bool]
 
 
-def session_completion(ctx, params, incomplete):
-    server = Server()
-    choices = [session.name for session in server.list_sessions()]
-    return sorted(str(c) for c in choices if str(c).startswith(incomplete))
-
-
 def create_freeze_subparser(
     parser: argparse.ArgumentParser,
 ) -> argparse.ArgumentParser:
+    """Augment :class:`argparse.ArgumentParser` with ``freeze`` subcommand."""
     parser.add_argument(
         dest="session_name",
         metavar="session-name",
@@ -45,14 +47,20 @@ def create_freeze_subparser(
         action="store",
     )
     parser.add_argument(
-        "-S", dest="socket_path", metavar="socket-path", help="pass-through for tmux -S"
+        "-S",
+        dest="socket_path",
+        metavar="socket-path",
+        help="pass-through for tmux -S",
     )
     parser.add_argument(
-        "-L", dest="socket_name", metavar="socket-name", help="pass-through for tmux -L"
+        "-L",
+        dest="socket_name",
+        metavar="socket-name",
+        help="pass-through for tmux -L",
     )
     parser.add_argument(
         "-f",
-        "--config-format",
+        "--workspace-format",
         choices=["yaml", "json"],
         help="format to save in",
     )
@@ -78,7 +86,10 @@ def create_freeze_subparser(
         help="don't prompt for confirmation",
     )
     parser.add_argument(
-        "--force", dest="force", action="store_true", help="overwrite the config file"
+        "--force",
+        dest="force",
+        action="store_true",
+        help="overwrite the workspace file",
     )
 
     return parser
@@ -88,45 +99,46 @@ def command_freeze(
     args: CLIFreezeNamespace,
     parser: t.Optional[argparse.ArgumentParser] = None,
 ) -> None:
-    """Snapshot a session into a config.
+    """Entrypoint for ``tmuxp freeze``, snapshot a tmux session into a tmuxp workspace.
 
-    If SESSION_NAME is provided, snapshot that session. Otherwise, use the
-    current session."""
+    If SESSION_NAME is provided, snapshot that session. Otherwise, use the current
+    session.
+    """
     server = Server(socket_name=args.socket_name, socket_path=args.socket_path)
 
     try:
         if args.session_name:
-            session = server.find_where({"session_name": args.session_name})
+            session = server.sessions.get(session_name=args.session_name, default=None)
         else:
             session = util.get_session(server)
 
         if not session:
-            raise TmuxpException("Session not found.")
+            raise exc.SessionNotFound
     except TmuxpException as e:
         print(e)
         return
 
-    sconf = freeze(session)
-    newconfig = config.inline(sconf)
-    configparser = ConfigReader(newconfig)
+    frozen_workspace = freezer.freeze(session)
+    workspace = freezer.inline(frozen_workspace)
+    configparser = ConfigReader(workspace)
 
     if not args.quiet:
         print(
             "---------------------------------------------------------------"
             "\n"
-            "Freeze does its best to snapshot live tmux sessions.\n"
+            "Freeze does its best to snapshot live tmux sessions.\n",
         )
     if not (
         args.answer_yes
         or prompt_yes_no(
-            "The new config *WILL* require adjusting afterwards. Save config?"
+            "The new workspace will require adjusting afterwards. Save workspace file?",
         )
     ):
         if not args.quiet:
             print(
                 "tmuxp has examples in JSON and YAML format at "
                 "<http://tmuxp.git-pull.com/examples.html>\n"
-                "View tmuxp docs at <http://tmuxp.git-pull.com/>."
+                "View tmuxp docs at <http://tmuxp.git-pull.com/>.",
             )
         sys.exit()
 
@@ -134,9 +146,12 @@ def command_freeze(
     while not dest:
         save_to = os.path.abspath(
             os.path.join(
-                get_config_dir(),
-                "{}.{}".format(sconf.get("session_name"), args.config_format or "yaml"),
-            )
+                get_workspace_dir(),
+                "{}.{}".format(
+                    frozen_workspace.get("session_name"),
+                    args.workspace_format or "yaml",
+                ),
+            ),
         )
         dest_prompt = prompt(
             "Save to: %s" % save_to,
@@ -148,16 +163,18 @@ def command_freeze(
 
         dest = dest_prompt
     dest = os.path.abspath(os.path.relpath(os.path.expanduser(dest)))
-    config_format = args.config_format
+    workspace_format = args.workspace_format
 
-    valid_config_formats: t.List["CLIOutputFormatLiteral"] = ["json", "yaml"]
+    valid_workspace_formats: t.List["CLIOutputFormatLiteral"] = ["json", "yaml"]
 
     def is_valid_ext(stem: t.Optional[str]) -> "TypeGuard[CLIOutputFormatLiteral]":
-        return stem in valid_config_formats
+        return stem in valid_workspace_formats
 
-    if not is_valid_ext(config_format):
+    if not is_valid_ext(workspace_format):
 
-        def extract_config_format(val: str) -> t.Optional["CLIOutputFormatLiteral"]:
+        def extract_workspace_format(
+            val: str,
+        ) -> t.Optional["CLIOutputFormatLiteral"]:
             suffix = pathlib.Path(val).suffix
             if isinstance(suffix, str):
                 suffix = suffix.lower().lstrip(".")
@@ -165,29 +182,33 @@ def command_freeze(
                     return suffix
             return None
 
-        config_format = extract_config_format(dest)
-        if not is_valid_ext(config_format):
-            config_format = prompt_choices(
+        workspace_format = extract_workspace_format(dest)
+        if not is_valid_ext(workspace_format):
+            _workspace_format = prompt_choices(
                 "Couldn't ascertain one of [%s] from file name. Convert to"
-                % ", ".join(valid_config_formats),
-                choices=valid_config_formats,
+                % ", ".join(valid_workspace_formats),
+                choices=t.cast(t.List[str], valid_workspace_formats),
                 default="yaml",
             )
+            assert is_valid_ext(_workspace_format)
+            workspace_format = _workspace_format
 
-    if config_format == "yaml":
-        newconfig = configparser.dump(
-            format="yaml", indent=2, default_flow_style=False, safe=True
+    if workspace_format == "yaml":
+        workspace = configparser.dump(
+            fmt="yaml",
+            indent=2,
+            default_flow_style=False,
+            safe=True,
         )
-    elif config_format == "json":
-        newconfig = configparser.dump(format="json", indent=2)
+    elif workspace_format == "json":
+        workspace = configparser.dump(fmt="json", indent=2)
 
     if args.answer_yes or prompt_yes_no("Save to %s?" % dest):
         destdir = os.path.dirname(dest)
         if not os.path.isdir(destdir):
             os.makedirs(destdir)
-        buf = open(dest, "w")
-        buf.write(newconfig)
-        buf.close()
+        with open(dest, "w", encoding=locale.getpreferredencoding(False)) as buf:
+            buf.write(workspace)
 
         if not args.quiet:
             print("Saved to %s." % dest)
