@@ -1,11 +1,21 @@
+"""Tmuxp example plugin for on_window_create."""
+
+import typing as t
+
 from tmuxp.plugin import TmuxpPlugin
 
+if t.TYPE_CHECKING:
+    from libtmux.window import Window
+
 
 class PluginOnWindowCreate(TmuxpPlugin):
-    def __init__(self):
-        self.message = "[+] This is the Tmuxp Test Plugin"
+    """Tmuxp plugin to test custom functionality on window creation."""
 
-    def on_window_create(self, window):
+    def __init__(self) -> None:
+        self.message: str = "[+] This is the Tmuxp Test Plugin"
+
+    def on_window_create(self, window: "Window") -> None:
+        """Apply hook that runs for tmux on session reattach."""
         if window.name == "editor":
             window.rename_window("plugin_test_owc")
         elif window.name == "owc_mw_test":
