@@ -1,14 +1,16 @@
 """Test for tmuxp tmuxinator configuration."""
+
+import typing as t
+
 import pytest
 
-from tmuxp.config_reader import ConfigReader
+from tests.fixtures import import_tmuxinator as fixtures
+from tmuxp._internal.config_reader import ConfigReader
 from tmuxp.workspace import importers, validation
 
-from ..fixtures import import_tmuxinator as fixtures
-
 
 @pytest.mark.parametrize(
-    "tmuxinator_yaml,tmuxinator_dict,tmuxp_dict",
+    ("tmuxinator_yaml", "tmuxinator_dict", "tmuxp_dict"),
     [
         (
             fixtures.test1.tmuxinator_yaml,
@@ -27,8 +29,13 @@ from ..fixtures import import_tmuxinator as fixtures
         ),  # Test importing <spec/fixtures/sample.yml>
     ],
 )
-def test_config_to_dict(tmuxinator_yaml, tmuxinator_dict, tmuxp_dict):
-    yaml_to_dict = ConfigReader._load(format="yaml", content=tmuxinator_yaml)
+def test_config_to_dict(
+    tmuxinator_yaml: str,
+    tmuxinator_dict: t.Dict[str, t.Any],
+    tmuxp_dict: t.Dict[str, t.Any],
+) -> None:
+    """Test exporting tmuxinator configuration to dictionary."""
+    yaml_to_dict = ConfigReader._load(fmt="yaml", content=tmuxinator_yaml)
     assert yaml_to_dict == tmuxinator_dict
 
     assert importers.import_tmuxinator(tmuxinator_dict) == tmuxp_dict
